@@ -19,10 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef ROSTER_WIDGET_H
-#define ROSTER_WIDGET_H
-
-#include <QtWidgets/QWidget>
+#pragma once
 
 #include "configuration/configuration-aware-object.h"
 #include "gui/actions/action-context-provider.h"
@@ -30,12 +27,19 @@
 #include "talkable/talkable.h"
 #include "exports.h"
 
+#include <QtCore/QPointer>
+#include <QtWidgets/QWidget>
+#include <injeqt/injeqt.h>
+
+class Configuration;
 class FilteredTreeView;
 class GroupTabBar;
 class GroupTabBarConfigurator;
 class GroupTalkableFilter;
+class InjectedFactory;
 class ProxyActionContext;
 class ModelChain;
+class StatusContainerManager;
 class TalkableProxyModel;
 class TalkableTreeView;
 
@@ -43,6 +47,10 @@ class KADUAPI RosterWidget : public QWidget, public ActionContextProvider, Confi
 {
 	Q_OBJECT
 
+	QPointer<Configuration> m_configuration;
+	QPointer<InjectedFactory> m_injectedFactory;
+	QPointer<StatusContainerManager> m_statusContainerManager;
+
 	GroupTabBar *GroupBar;
 	QScopedPointer<GroupTabBarConfigurator> TabBarConfigurator;
 
@@ -61,14 +69,20 @@ class KADUAPI RosterWidget : public QWidget, public ActionContextProvider, Confi
 	ModelChain * createModelChain();
 	void createTalkableWidget(QWidget *parent);
 
-protected:
-	void configurationUpdated();
+private slots:
+	INJEQT_SET void setConfiguration(Configuration *configuration);
+	INJEQT_SET void setInjectedFactory(InjectedFactory *injectedFactory);
+	INJEQT_SET void setStatusContainerManager(StatusContainerManager *statusContainerManager);
+	INJEQT_INIT void init();
 
-	void compositingEnabled();
-	void compositingDisabled();
+protected:
+	virtual void configurationUpdated() override;
+
+	virtual void compositingEnabled() override;
+	virtual void compositingDisabled() override;
 
 public:
-	explicit RosterWidget(QWidget *parent = 0);
+	explicit RosterWidget(QWidget *parent = nullptr);
 	virtual ~RosterWidget();
 
 	void clearFilter();
@@ -88,5 +102,3 @@ signals:
 	void talkableActivated(const Talkable &talkable);
 
 };
-
-#endif // ROSTER_WIDGET_H
